@@ -1,7 +1,7 @@
 /*
  *  kalarmapp.h  -  the KAlarm application object
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2001-2021 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2022 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -13,8 +13,7 @@
 #include "eventid.h"
 #include "kamail.h"
 #include "preferences.h"
-
-#include <KAlarmCal/KAEvent>
+#include "kalarmcalendar/kaevent.h"
 
 #include <QApplication>
 #include <QPointer>
@@ -210,8 +209,8 @@ private:
     {
         ActionQEntry(QueuedAction a, const EventId& id) : action(a), eventId(id) { }
         ActionQEntry(QueuedAction a, const EventId& id, const QString& resId) : action(a), eventId(id), resourceId(resId) { }
-        ActionQEntry(const KAEvent& e, QueuedAction a = QueuedAction::Handle) : action(a), event(e) { }
-        ActionQEntry() { }
+        explicit ActionQEntry(const KAEvent& e, QueuedAction a = QueuedAction::Handle) : action(a), event(e) { }
+        ActionQEntry() = default;
         QueuedAction  action;
         EventId       eventId;
         KAEvent       event;
@@ -298,5 +297,4 @@ inline KAlarmApp* theApp()  { return KAlarmApp::instance(); }
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(KAlarmApp::ExecAlarmFlags)
 
-
 // vim: et sw=4:
